/*
 * file CcViewTag.java
 * 
 * Licensed Materials - Property of IBM
 * Restricted Materials of IBM 
 *
 * com.ibm.rational.wvcm.stp.cc.CcViewTag
 *
 * (C) Copyright IBM Corporation 2008.  All Rights Reserved.
 * Note to U.S. Government Users Restricted Rights:  Use, duplication or 
 * disclosure restricted by GSA ADP  Schedule Contract with IBM Corp.
 */

package com.ibm.rational.wvcm.stp.cc;

import static com.ibm.rational.wvcm.stpex.StpExBase.PROPERTY_NAMESPACE;

import javax.wvcm.WvcmException;
import javax.wvcm.PropertyNameList.PropertyName;

import com.ibm.rational.wvcm.stpex.StpExBase;
import com.ibm.rational.wvcm.stpex.StpExEnumeration;
import com.ibm.rational.wvcm.stpex.StpExEnumerationBase;

/**
 * <p>
 * A proxy for a ClearCase view tag - the handle by which a ClearCase view
 * is identified and managed.
 * </p>
 * <p>
 * View tags are treated as distinct objects from views in order to allow the 
 * for retrieval of basic view info and passing of handles to views without
 * incurring the overhead of actually opening a real view connection.
 * </p>
 */

public interface CcViewTag extends CcResource {
    
    /**
     * Type of ClearCase view.
     * View type is one of
     * <bl>
     * <li>Dynamic.
     * </li>
     * <li>Snapshot.
     * </li>
     * <li>Web.
     * </li>
     * </bl>
     * For more information, see the ClearCase Reference Manual.
     */
    enum ViewType implements StpExEnumeration {
        /** This is a dynamic view. */
        DYNAMIC,

        /** This is a snapshot view */
        SNAPSHOT,

        /** This a web view. */
        WEB;
    }

    /** Is this a tag for a UCM view? */
    PropertyName<Boolean> IS_UCM_VIEW =
        new PropertyName<Boolean>(PROPERTY_NAMESPACE,
                                  "is-ucm-view");
    
    /**
     * Returns the value of this proxy's {@link #IS_UCM_VIEW} property.
     * 
     * @return true if the view tag is for a UCM view, else false
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    boolean getIsUcmView() throws WvcmException;

    /** The view to which this tag refers */
    PropertyName<CcView> VIEW =
        new PropertyName<CcView>(PROPERTY_NAMESPACE, "view");
    
    /**
     * Returns the value of this proxy's {@link #VIEW} property.
     * 
     * @return the view to which this tag refers, as CcView instance
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    CcView getView() throws WvcmException;

    /** Kind of view to which this tag refers */
    PropertyName<ViewType> VIEW_TYPE =
        new PropertyName<ViewType>(PROPERTY_NAMESPACE,
                                   "view-tag-view-type");
    
    /**
     * Returns the value  of this proxy's {@link #VIEW_TYPE} property.
     * 
     * @return Kind of view this tag refers to.
     * @throws WvcmException
     *             if this proxy doesn't define a value for this property.
     */
    ViewType getViewType () throws WvcmException;
    
    /** The registry region this tag resides in */
    PropertyName<CcRegistryRegion> REGISTRY_REGION =
        new PropertyName<CcRegistryRegion>(PROPERTY_NAMESPACE, "viewtag-registry-region");
    
    /**
     * Returns the value of this proxy's {@link #REGISTRY_REGION} property.
     * 
     * @return The registry region of this view tag.
     * @throws WvcmException 
     *             if this proxy doesn't define a value for this property.
     */
    CcRegistryRegion getRegistryRegion() throws WvcmException;
}
